@@ -13,14 +13,14 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-set -ex
+# set -ex
 
 # Install freezer devstack integration
-export DEVSTACK_LOCAL_CONFIG="enable_plugin freezer-api https://git.openstack.org/openstack/freezer-api"
+#export DEVSTACK_LOCAL_CONFIG="enable_plugin freezer-api https://git.openstack.org/openstack/freezer-api"
 
-export DEVSTACK_GATE_TEMPEST_REGEX="freezer_api_tempest_plugin"
+export DEVSTACK_GATE_TEMPEST_REGEX="freezer_tempest_plugin.tests.freezer_api"
 
 export PROJECTS="openstack/python-freezerclient $PROJECTS"
 
 # Invoke default behavior.
-$BASE/new/devstack-gate/devstack-vm-gate.sh
+# $BASE/new/devstack-gate/devstack-vm-gate.sh
