@@ -46,7 +46,38 @@ def api_common_opts():
                     default=9090,
                     dest='bind_port',
                     help='Port number to listen on. Default is 9090'
-                    )
+                    ),
+        cfg.BoolOpt('enable_v1_api',
+                    default=True,
+                    help="""Deploy the v1 OpenStack Freezer API.
+When this option is set to ``True``, Freezer-api service will respond to
+requests on registered endpoints conforming to the v1 OpenStack Freezer API.
+NOTES:
+    * Multi-tenancy is not supported under this api version.
+    * Everything is user based.
+    * Freezer api v1 doesn't support Oslo.db.
+    * Use elasticsearch db with v1 api version
+Possible values:
+    * True
+    * False
+Related options:
+    * enable_v2_api
+                    """),
+        cfg.BoolOpt('enable_v2_api',
+                    default=True,
+                    help="""Deploy the v2 OpenStack Freezer API.
+When this option is set to ``True``, Freezer-api service will respond to
+requests on registered endpoints conforming to the v2 OpenStack Freezer api.
+    NOTES:
+        * Multi-tenancy is supported under this api version.
+        * Freezer api v2 supports Oslo.db.
+        * Recommended to use oslo.db with api v2
+    Possible values:
+        * True
+        * False
+    Related options:
+        * enable_v1_api
+                        """)
     ]
 
     return _COMMON
@@ -54,7 +85,7 @@ def api_common_opts():
 
 def parse_args(args=[]):
     CONF.register_cli_opts(api_common_opts())
-    driver.register_elk_opts()
+    driver.register_storage_opts()
     # register paste configuration
     paste_grp = cfg.OptGroup('paste_deploy',
                              'Paste Configuration')
@@ -116,8 +147,9 @@ def find_paste_config():
 def list_opts():
     _OPTS = {
         None: api_common_opts(),
-        'storage': driver.get_elk_opts(),
         'paste_deploy': paste_deploy,
         AUTH_GROUP: AUTH_OPTS
     }
+    # update the current list of opts with db backend drivers opts
+    _OPTS.update(driver.get_storage_opts())
     return _OPTS.items()
